import 'package:ocg_app/ocg_app.dart';
import 'package:bloc/bloc.dart';
import 'package:ocg_login/src/repository/login.dart';
import 'package:ocg_user/ocg_user.dart';

import 'event.dart';
import 'state.dart';

class LoginBloc extends Bloc<LoginEvent, LoginState> {
  final LoginRepository repository;
  final UserRepository userRepository;
  LoginBloc(
    this.repository,
    this.userRepository,
  ) : super(LoginIdleState());

  @override
  Stream<LoginState> mapEventToState(LoginEvent event) async* {
    if (event is LoginCheckEvent) {
      AppResponse<bool> loginResponse = await repository.isLoggedIn();
      if (loginResponse.isSuccess && loginResponse.data) {
        AppResponse<User> userResponse = await userRepository.getSelf();
        if (userResponse.isSuccess)
          yield LoginExistState(userResponse.data);
        else
          yield LoginNotExistState();
      } else {
        yield LoginNotExistState();
      }
    }
    if (event is LoginNotExistState) {
      yield LoginMobileEmptyState();
    }
    if (event is LoginMobileEvent) {
      yield LoginLoadingState();

      var response = await repository.sendOTP(event.mobileNumber);
      if (response.isSuccess)
        yield LoginOTPNotVerifiedState(event.mobileNumber);
      else {
        yield LoginErrorState(response.error);
      }
    }
    if (event is LoginOTPEvent) {
      yield LoginLoadingState();
      var response = await repository.verifyOTP(event.mobileNumber, event.otp);
      if (response.isSuccess) {
        AppResponse<User> userResponse = await userRepository.getSelf();
        if (userResponse.isSuccess)
          yield LoginExistState(userResponse.data);
        else
          yield LoginErrorState(userResponse.error);
      } else {
        yield LoginErrorState(response.error);
      }
    }
  }
}
