import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_login/src/widgets/continue_button.dart';
import 'package:ocg_user/ocg_user.dart';

class ProfileCompletionScreen extends StatefulWidget {
  @override
  _ProfileCompletionScreenState createState() =>
      _ProfileCompletionScreenState();
}

class _ProfileCompletionScreenState extends State<ProfileCompletionScreen> {
  final GlobalKey<FormState> key = GlobalKey<FormState>();
  final GlobalKey<ScaffoldState> scaffoldKey = GlobalKey<ScaffoldState>();
  bool isUpdate;

  File selectedImage;

  User user;
  bool isUploading;
  String filePath;
  TextEditingController statusController;

  @override
  void initState() {
    super.initState();
    isUploading = false;
    isUpdate = false;
    statusController = TextEditingController();
    WidgetsBinding.instance.addPostFrameCallback((val) {
      var arguments = ModalRoute.of(context).settings.arguments;
      if (arguments is Map) {
        isUpdate = arguments["isUpdate"] ?? false;
      }
      if (mounted) {}
    });
  }

  String getDefault() {
    return AppUIHelper.of(context).getPlaceholderImage(user?.name ?? "Me");
  }

  String get currentPick => (!InputHelper.isBlank(filePath))
      ? filePath
      : !InputHelper.isBlank(user?.profilePic)
          ? user?.profilePic
          : AppUIHelper.of(context).getPlaceholderImage(user?.name ?? "Me");

  @override
  Widget build(BuildContext context) {
    return AnnotatedRegion<SystemUiOverlayStyle>(
      value: SystemUiOverlayStyle.dark,
      child: Scaffold(
        key: scaffoldKey,
        appBar: isUpdate ? AppBar() : null,
        body: SafeArea(
          bottom: false,
          child: user == null
              ? Center(
                  child: CircularProgressIndicator(),
                )
              : SizedBox(
                  height: MediaQuery.of(context).size.height -
                      MediaQuery.of(context).padding.bottom,
                  child: SingleChildScrollView(
                    child: Padding(
                      padding:
                          EdgeInsets.symmetric(vertical: 16, horizontal: 24),
                      child: Form(
                        key: key,
                        child: Column(
                          mainAxisSize: MainAxisSize.min,
                          crossAxisAlignment: CrossAxisAlignment.stretch,
                          children: <Widget>[
                            SizedBox(
                              height: 24,
                            ),
                            RichText(
                              text: TextSpan(children: [
                                TextSpan(
                                  text: (isUpdate ? "Update" : "Enter") +
                                      " your details",
                                  style: TextStyle(
                                    color: Colors.black,
                                    fontSize: 24,
                                  ),
                                ),
                              ], style: TextStyle(fontWeight: FontWeight.w600)),
                            ),
                            SizedBox(
                              height: 36,
                            ),
                            Center(child: buildProfile()),
                            SizedBox(
                              height: 60,
                            ),
                            TextFormField(
                              decoration: InputDecoration(
                                labelText: "Name",
                              ),
                              onChanged: (val) {
                                setState(() {
                                  user = user.copyWith(name: val);
                                });
                              },
                              validator: (value) {
                                return value.isEmpty
                                    ? "Please enter your name"
                                    : null;
                              },
                            ),
                            SizedBox(
                              height: 36,
                            ),
                            SizedBox(
                              height: 48,
                            ),
                            ContinueButton(
                                title: isUpdate ? "Update" : "Continue",
                                showIcon: !isUpdate,
                                color: Theme.of(context).primaryColor,
                                onPressed: () async {}),
                            SizedBox(
                              height: 40,
                            ),
                            isUpdate
                                ? Container()
                                : Center(
                                    child: Text(
                                      "© 2020 OCG Connect Inc. All rights reserved.",
                                      style: TextStyle(
                                          color: Colors.black54,
                                          fontSize: 15,
                                          fontWeight: FontWeight.w400),
                                      textAlign: TextAlign.center,
                                    ),
                                  ),
                          ],
                        ),
                      ),
                    ),
                  ),
                ),
        ),
      ),
    );
  }

  List<String> get dropDownItems => [
        "Available",
        "Busy",
        "At work",
      ];

  Widget buildProfile() {
    return Stack(
      alignment: Alignment.topRight,
      children: <Widget>[
        Stack(
          alignment: Alignment.topRight,
          children: <Widget>[
            Container(
              decoration: BoxDecoration(
                  border: Border.all(color: Color(0xffeeeeee), width: 3),
                  shape: BoxShape.circle),
              child: CircleAvatar(
                radius: 64,
                backgroundImage: NetworkImage(currentPick),
                backgroundColor: Colors.white,
                child: Center(
                  child:
                      isUploading ? CircularProgressIndicator() : Container(),
                ),
              ),
            ),
            isUploading
                ? Container(
                    width: 32,
                    height: 32,
                  )
                : Container(
                    margin: EdgeInsets.only(right: 2),
                    decoration: BoxDecoration(
                        shape: BoxShape.circle, color: Colors.blue),
                    padding: const EdgeInsets.all(8.0),
                    child: Icon(
                      Icons.edit,
                      color: Colors.black,
                      size: 20,
                    ),
                  )
          ],
        ),
      ],
    );
  }
}
